<!--
SPDX-FileCopyrightText: 2021 The octopy-energy Authors

SPDX-License-Identifier: Apache-2.0
-->

# Python module to access Octopus Energy APIs

This module allows access to [Octopus Energy APIs](https://developer.octopus.energy/docs/api/)
to query for meter readings and other information.
